@@ -45,10 +45,10 @@ def is_recoverable(exception):
 
 
 def connect():
-    connectTo(os.environ["BATCHX_ENDPOINT"], os.environ["BATCHX_TOKEN"], True);
+    connect_to(os.environ["BATCHX_ENDPOINT"], os.environ["BATCHX_TOKEN"], True);
 
 @retry(RecoverableException, delay=CALL_DELAY, backoff=CALL_BACKOFF, max_delay=CALL_MAX_DELAY, tries=MAX_TRIES)
-def connectTo(endpoint, token, secure):
+def connect_to(endpoint, token, secure):
     global channel, bx_token, bx_endpoint
     if channel is None:
         try:
@@ -80,7 +80,7 @@ def current_access_token_is_valid():
     if access_token is None:
         return False
     else:
-        access_token_dict = jwt.decode(access_token, verify=False)
+        access_token_dict = jwt.decode(access_token, options={"verify_signature":False})
         return access_token_dict['exp'] > time.time()
 
 
@@ -118,7 +118,7 @@ def login():
     """ Connect to server and obtain an access token if needed."""
     global channel, bx_token, access_token
     if bx_token is not None:
-        user_id = jwt.decode(bx_token, verify=False)['batchx-id']
+        user_id = jwt.decode(bx_token, options={"verify_signature":False})['batchx-id']
         request_data = auth_pb2.RefreshTokenRequest(user_name=user_id, refresh_token=bx_token)
         response = make_call(auth_pb2_grpc.AuthServiceStub(channel).RefreshToken, request_data, include_metadata=False)
         access_token = response.access_token
@@ -128,8 +128,6 @@ def login():
 
 from . import environment_pb2
 from . import environment_pb2_grpc
-
-
 class EnvironmentService:
 
     def GetEnvironment(self, request):
@@ -145,8 +143,6 @@ class EnvironmentService:
 
 from . import common_pb2
 from . import common_pb2_grpc
-
-
 class CommonService:
 
     def IntRangeFilter(self, **kwargs):
@@ -179,8 +175,6 @@ class CommonService:
 
 from . import health_pb2
 from . import health_pb2_grpc
-
-
 class HealthService:
 
     def HealthCheckRequest(self, **kwargs):
@@ -192,8 +186,6 @@ class HealthService:
 
 from . import tag_pb2
 from . import tag_pb2_grpc
-
-
 class TagService:
 
     def CreateTag(self, request):
@@ -268,8 +260,6 @@ class TagService:
 
 from . import audit_pb2
 from . import audit_pb2_grpc
-
-
 class AuditService:
 
     def ListEvents(self, request):
@@ -288,8 +278,6 @@ class AuditService:
 
 from . import docker_pb2
 from . import docker_pb2_grpc
-
-
 class DockerService:
 
     def DockerImageCoordinates(self, **kwargs):
@@ -298,8 +286,6 @@ class DockerService:
 
 from . import profile_pb2
 from . import profile_pb2_grpc
-
-
 class ProfileService:
 
     def Profile(self, **kwargs):
@@ -308,8 +294,6 @@ class ProfileService:
 
 from . import filesystem_pb2
 from . import filesystem_pb2_grpc
-
-
 class FilesystemService:
 
     def CancelUpload(self, request):
@@ -466,8 +450,6 @@ class FilesystemService:
 
 from . import user_pb2
 from . import user_pb2_grpc
-
-
 class UserService:
 
     def GetUser(self, request):
@@ -493,8 +475,6 @@ class UserService:
 
 from . import job_pb2
 from . import job_pb2_grpc
-
-
 class JobService:
 
     def Cancel(self, request):
@@ -557,6 +537,15 @@ class JobService:
         check()
         return make_call(job_pb2_grpc.JobServiceStub(channel).TagWorkflow, request)
 
+    def Run(self, submit_request):
+        job = self.Submit(submit_request)
+        request_stream = self.StreamRequest(environment=submit_request.environment, job_id=job.job_id)
+        response = self.Stream(request_stream)
+        for r in response:
+            for job_event in r.event:
+                if job_event.WhichOneof("type") == "return_value":
+                    return getattr(job_event, job_event.WhichOneof("type"));
+
     def CancelRequest(self, **kwargs):
         return job_pb2.CancelRequest(**kwargs)
 
@@ -659,8 +648,6 @@ class JobService:
 
 from . import image_pb2
 from . import image_pb2_grpc
-
-
 class ImageService:
 
     def CloneImage(self, request):
@@ -753,8 +740,6 @@ class ImageService:
 
 from . import admin_pb2
 from . import admin_pb2_grpc
-
-
 class AdminService:
 
     def AddEnvironmentCredits(self, request):
@@ -813,8 +798,6 @@ class AdminService:
 
 from . import organization_pb2
 from . import organization_pb2_grpc
-
-
 class OrganizationService:
 
     def GetOrganization(self, request):
@@ -860,8 +843,6 @@ class OrganizationService:
 
 from . import picture_pb2
 from . import picture_pb2_grpc
-
-
 class PictureService:
 
     def CompleteUpload(self, request):
@@ -897,8 +878,6 @@ class PictureService:
 
 from . import token_pb2
 from . import token_pb2_grpc
-
-
 class TokenService:
 
     def AddToken(self, request):
@@ -914,8 +893,6 @@ class TokenService:
 
 from . import auth_pb2
 from . import auth_pb2_grpc
-
-
 class AuthService:
 
     def ConfirmForgotPassword(self, request):
@@ -971,8 +948,6 @@ class AuthService:
 
 from . import log_pb2
 from . import log_pb2_grpc
-
-
 class LogService:
 
     def LogRecord(self, **kwargs):
@@ -981,8 +956,6 @@ class LogService:
 
 from . import provider_pb2
 from . import provider_pb2_grpc
-
-
 class ProviderService:
 
     def GetMetrics(self, request):
